@@ -82,6 +82,7 @@ void ExerciseWindow::sendClosed()
 
 void ExerciseWindow::loadExercise(QList<QString> name)
 {
+    qDebug () << "ExerciseWindow::loadExercise 1";
     int i = 0;
     QList <QString> list = xml->getHistoryByExercise(name.first());
 
@@ -94,7 +95,7 @@ void ExerciseWindow::loadExercise(QList<QString> name)
         i++;
     }
     currentSet = 0;
-
+    qDebug () << "ExerciseWindow::loadExercise 2";
     bool firstTime = false;
     if(exercises.count() == 0)
         firstTime = true;
@@ -103,7 +104,7 @@ void ExerciseWindow::loadExercise(QList<QString> name)
 
     QList <QString> tmp;
     QList<QString> settings = xml->loadSettings();
-
+    qDebug () << "ExerciseWindow::loadExercise 3";
     settings.removeLast();
     SEC = settings.takeLast().toInt();
     MIN = settings.takeLast().toInt();
@@ -116,6 +117,7 @@ void ExerciseWindow::loadExercise(QList<QString> name)
     if(settings.takeFirst() == "1")
         soundActive = true;
 
+    qDebug () << "ExerciseWindow::loadExercise 4";
     if(exercises.count() == 1)
     {
         currentExercise = exercises.first();
@@ -123,7 +125,7 @@ void ExerciseWindow::loadExercise(QList<QString> name)
         tmp = xml->openEx(currentExercise);
         tmp.removeFirst();
         currentGroup = tmp.takeFirst();
-
+        qDebug () << "ExerciseWindow::loadExercise 5";
         set = SET; min = MIN; sec = SEC;
         strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
 
@@ -138,15 +140,19 @@ void ExerciseWindow::loadExercise(QList<QString> name)
 
         btnShake->setEnabled(true);
         myThread->start(QThread::NormalPriority);
+        qDebug () << "ExerciseWindow::loadExercise 6";
     }
 
     if(firstTime == true && exercises.count() > 1)
     {
+        qDebug () << "ExerciseWindow::loadExercise 7";
         ed = new ExerciseDialog(this);
         connect(ed,SIGNAL(exerciseName(QString)),this, SLOT(setCurrentExercise(QString)));
         connect(ed,SIGNAL(destroyDialog()),this,SLOT(sendDestroyDialog()));
         ed->load(exercises);
+        qDebug () << "ExerciseWindow::loadExercise 8";
         ed->show();
+        qDebug () << "ExerciseWindow::loadExercise 9";
     }
 
 
@@ -159,25 +165,30 @@ void ExerciseWindow::sendDestroyDialog()
 
 void ExerciseWindow::openED()
 {
+    qDebug () << "ExerciseWindow::openED 1";
     if(exercises.count() > 1)
     {
+        qDebug () << "ExerciseWindow::openED 2";
         ed = new ExerciseDialog(this);
         connect(ed,SIGNAL(exerciseName(QString)),this, SLOT(setCurrentExercise(QString)));
+        qDebug () << "ExerciseWindow::openED 3";
         connect(ed,SIGNAL(destroyDialog()),this,SLOT(sendDestroyDialog()));
         ed->load(exercises);
+        qDebug () << "ExerciseWindow::openED 4";
         ed->show();
     }
 }
 
 void ExerciseWindow::setCurrentExercise(QString name)
 {
+    qDebug () << "ExerciseWindow::setCurrentExercise 1";
     int i = 0;
     QList <QString> list;
 
     currentSet = 0;
 
     list = xml->getHistoryByExercise(name);
-
+    qDebug () << "ExerciseWindow::setCurrentExercise 2";
     while(!list.isEmpty())
     {
         status[i] = list.takeFirst();
@@ -186,7 +197,7 @@ void ExerciseWindow::setCurrentExercise(QString name)
 
         i++;
     }
-
+    qDebug () << "ExerciseWindow::setCurrentExercise 3";
     QList <QString> tmp;
     currentExercise = name;
     QDBusMessage reply;
@@ -194,7 +205,7 @@ void ExerciseWindow::setCurrentExercise(QString name)
     tmp = xml->openEx(currentExercise);
     tmp.removeFirst();
     currentGroup = tmp.takeFirst();
-
+    qDebug () << "ExerciseWindow::setCurrentExercise 4";
 
     set = SET; min = MIN; sec = SEC;
     strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
@@ -207,12 +218,13 @@ void ExerciseWindow::setCurrentExercise(QString name)
                        reps[currentSet] + " was " + status[currentSet] + ".");
     else
         label->setText("Exercise: " + currentExercise +  "\nShake when set is done.");
-
+    qDebug () << "ExerciseWindow::setCurrentExercise 5";
     btnShake->setEnabled(true);
     myThread->start(QThread::NormalPriority);
 
 
     reply = interface->call(MCE_TKLOCK_MODE_CHANGE_REQ, "locked");
+    qDebug () << "ExerciseWindow::setCurrentExercise 6";
 }
 
 void ExerciseWindow::changeEvent(QEvent *event)
@@ -287,13 +299,13 @@ void ExerciseWindow::createActions()
 
 void ExerciseWindow::updateTime()
 {
-
+    qDebug () << "updateTime 1";
     //count down wait
     strMin.setNum(min); strSec.setNum(sec); strSet.setNum(set);
     QString str = strMin + ":" + strSec + " rest left (" + strSet + "set)";
     btnShake->setEnabled(false);
     label->setText(str);
-
+    qDebug () << "updateTime 2";
     if(sec <= 0)
     {
         sec = 60;
@@ -311,7 +323,7 @@ void ExerciseWindow::updateTime()
 
             btnShake->setEnabled(true);
 
-
+            qDebug () << "updateTime 3";
 
             timer->stop();
 
@@ -326,7 +338,7 @@ void ExerciseWindow::updateTime()
                 sound->playWait();
 
             }
-
+            qDebug () << "updateTime 4";
             myThread->start(QThread::NormalPriority);
 
             if(vibrateActive == true)
@@ -337,6 +349,7 @@ void ExerciseWindow::updateTime()
                 QObject::connect(tmr, SIGNAL(timeout()), this, SLOT(stopVibrate()));
                 tmr->start(3000);  //ndra hr fr olika vibrationslngd
             }
+            qDebug () << "updateTime 5";
         }
     }
     sec--;
@@ -370,7 +383,7 @@ void ExerciseWindow::checkProximity(QString data)
 void ExerciseWindow::checkAcc(QString x)
 {
 
-
+    qDebug () << "checkAcc 1";
     if(x.toInt() > 2200 || x.toInt() < -2200)
     {
         if(proximity == false)
@@ -380,15 +393,17 @@ void ExerciseWindow::checkAcc(QString x)
             tmr->setSingleShot(true);
             QObject::connect(tmr, SIGNAL(timeout()), this, SLOT(stopVibrate()));
             tmr->start(1000);  //ndra hr fr olika vibrationslngd
-
+            qDebug () << "checkAcc 2";
             shaked();
         }
 
     }
+
 }
 
 void ExerciseWindow::shaked()
 {
+    qDebug () << "shaked 1";
     currentSet++;
     QDBusMessage reply;
     if(set == -1)
@@ -400,15 +415,18 @@ void ExerciseWindow::shaked()
 
     if(set == 0)
     {
+        qDebug () << "shaked 2";
         timer->stop();
         if(soundActive == true)
         {
+            qDebug () << "shaked 3";
             QDBusConnection::sessionBus().send(pause);
             tmrPause = new QTimer(this);
             tmrPause->setSingleShot(true);
             QObject::connect(tmrPause, SIGNAL(timeout()), this, SLOT(resumeMusic()));
             tmrPause->start(3000);  //ndra hr fr olika vibrationslngd
             sound->playDone();
+            qDebug () << "shaked 4";
             //wait x ms
             //QDBusConnection::sessionBus().send(resume);
 
@@ -416,31 +434,39 @@ void ExerciseWindow::shaked()
 
         if(exercises.count() > 1)
         {
+            qDebug () << "shaked 5";
             exercises.removeOne(currentExercise);
             loadExercise(exercises);
 
             wd = new WeightDialog(this);
             connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
+            qDebug () << "shaked 6";
             wd->load(currentExercise, currentGroup,"1");
             wd->show();
+            qDebug () << "shaked 7";
             return;
+
         }
         else
         {
             label->setText("Exercise(s) completed!");
             btnShake->setEnabled(false);
-
+            qDebug () << "shaked 8";
             wd = new WeightDialog(this);
             connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
+            qDebug () << "shaked 9";
             wd->load(currentExercise, currentGroup,"1");
             wd->show();
+            qDebug () << "shaked 10";
             return;
         }
-
+        qDebug () << "shaked 11";
         wd = new WeightDialog(this);
         connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
+        qDebug () << "shaked 12";
         wd->load(currentExercise, currentGroup, "1");
         wd->show();
+        qDebug () << "shaked 13";
     }
 
     //Start wait and count down
@@ -449,33 +475,42 @@ void ExerciseWindow::shaked()
     label->setText(str);
     btnShake->setEnabled(false);
 
-
+    qDebug () << "shaked 14";
     reply = interface->call(MCE_TKLOCK_MODE_CHANGE_REQ, "locked");
 
     timer->start(1000); //count down every second
     myThread->quit(); //stop check accelerometer
+    qDebug () << "shaked 15";
 }
 
 void ExerciseWindow::reopenWD()
 {
     QString str;
-
+    qDebug () << "reopenWD 1";
     if(wdCount > SET)
     {
+        qDebug () << "reopenWD 2";
         if(exercises.count() > 1)
+        {
+            qDebug () << "reopenWD 3";
             openED();
+        }
         return;
     }
     else
     {
+        qDebug () << "reopenWD 4";
         str.setNum(wdCount);
         wd = new WeightDialog(this);
         wd->load(currentExercise, currentGroup, str);
+        qDebug () << "reopenWD 5";
         connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
         wd->show();
+        qDebug () << "reopenWD 6";
     }
 
     wdCount++;
+    qDebug () << "reopenWD 7";
 }
 
 
