@@ -15,7 +15,7 @@ FoodDialog::FoodDialog(QWidget *parent)
     modelType->appendRow(new QStandardItem(tr("Drink")));
     modelType->appendRow(new QStandardItem(tr("Food")));
 
-    btnType = new QMaemo5ValueButton("Product");
+    btnType = new QMaemo5ValueButton("Type");
     btnType->setValueLayout(QMaemo5ValueButton::ValueUnderText);
     selectorType = new QMaemo5ListPickSelector;
     selectorType->setModel(modelType);
@@ -66,11 +66,32 @@ void FoodDialog::load()
 
 void FoodDialog::save()
 {
-    int kcal = xml->getCaloriesByName(btnName->valueText());
+    QList <int> list;
+    int kcal, protein, carbohydrate, fat;
+    QString k,p,c,f;
 
+    list = xml->getCaloriesByName(btnName->valueText());
+
+    kcal = list.takeFirst();
     kcal *= btnAmount->valueText().toInt();
     kcal /= 100;
-    QString tmp; tmp.setNum(kcal);
-    xml->saveEatenFood(tmp);
+    k.setNum(kcal);
+
+    protein = list.takeFirst();
+    protein *= btnAmount->valueText().toInt();
+    protein /= 100;
+    p.setNum(protein);
+
+    carbohydrate = list.takeFirst();
+    carbohydrate *= btnAmount->valueText().toInt();
+    carbohydrate /= 100;
+    c.setNum(carbohydrate);
+
+    fat = list.takeFirst();
+    fat *= btnAmount->valueText().toInt();
+    fat /= 100;
+    f.setNum(fat);
+
+    xml->saveEatenFood(k,p,c,f);
     hide();
 }
