@@ -13,7 +13,6 @@ class NewIngredientWindow : public QDialog
 public:
     explicit NewIngredientWindow(QWidget *parent = 0);
     void load();
-
 signals:
 
 private:
@@ -22,10 +21,6 @@ private:
     QPushButton *btnSave;
     QLineEdit *txtName;
 
-    QMaemo5ValueButton *btnCalories;
-    QMaemo5ListPickSelector *selectorCalories;
-    QStandardItemModel *modelCalories;
-
     QMaemo5ValueButton *btnCarbohydrate;
     QMaemo5ListPickSelector *selectorCarbohydrate;
     QStandardItemModel *modelCarbohydrate;
